@@ -3,14 +3,15 @@ from .model.frame.NICartographyFrameCScan import NICartographyFrameCScan
 
 
 def open_cscan(cscanFilePath: str, displayResult: bool = True) -> NICartographyFrameCScan:
-    return NICartographyFrameCScan(gateway.jvm.agi.ndtkit.api.NDTKitCScanInterface.openCScan(cscanFilePath, displayResult)[0])
+    cscan_frame_java = gateway.jvm.agi.ndtkit.api.NDTKitCScanInterface.openCScan(cscanFilePath, displayResult)[0]  # pyright: ignore[reportIndexIssue]
+    return NICartographyFrameCScan(cscan_frame_java)
 
 
 def save_cscan(cscan: NICartographyFrameCScan, filepath: str):
     return gateway.jvm.agi.ndtkit.api.NDTKitCScanInterface.saveCscan(cscan._java_object, filepath)
 
 
-def create_cscan(data: list[list[float]], acquisition_name: str, x_res: float, y_res: float) -> NICartographyFrameCScan:
+def create_cscan(data: list[list[float]], acquisition_name: str, x_res: float, y_res: float) -> NICartographyFrameCScan | None:
     parameters = [
         {
             "type": "float[][]",
